satsim.generator package — SatSim 0.22.1 documentation

# satsim.generator package

## Subpackages

- satsim.generator.obs package
  - Submodules
  - satsim.generator.obs.breakup module
    - `breakup_from_tle()`
    - `collision_from_tle()`
  - satsim.generator.obs.cso module
    - `one()`
  - satsim.generator.obs.geometry module
    - `circle()`
    - `cone()`
    - `sphere()`
  - satsim.generator.obs.io module
    - `tle_file()`
  - satsim.generator.obs.rpo module
    - `rpo_from_tle()`